using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IHistoricalApi
    {
        /// <summary>
        /// Get historical stats for categories 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="keywordFilter">Filter answers to cateogry names containing a particular keyword</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Categories&gt;</returns>
        List<Categories> CategoriesGet (string country, string subcountry, string fromDate, string toDate, string keywordFilter, int? lines, int? offset);
        /// <summary>
        /// Get history for category ID 
        /// </summary>
        /// <param name="id">category id</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Category&gt;</returns>
        List<Category> CategoryGet (string id, string country, string subcountry, string fromDate, string toDate);
        /// <summary>
        /// Get history for domain name 
        /// </summary>
        /// <param name="domain">domain name (no subdomain allowed)</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Domain&gt;</returns>
        List<Domain> DomainGet (string domain, string country, string subcountry, string fromDate, string toDate);
        /// <summary>
        /// Get historical stats for domains 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="urlFilter">Filter answers to domains including a specified string</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Domains&gt;</returns>
        List<Domains> DomainsGet (string country, string subcountry, string fromDate, string toDate, string urlFilter, int? lines, int? offset);
        /// <summary>
        /// Get page history for URL 
        /// </summary>
        /// <param name="url">Fully qualified page url. URL needs to be URL encoded</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Page&gt;</returns>
        List<Page> PageGet (string url, string country, string subcountry, string fromDate, string toDate);
        /// <summary>
        /// Get historical stats for pages 
        /// </summary>
        /// <param name="presetFilter">Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, last 30 days)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, last 30 days)</param>
        /// <param name="country">ISO_3166 country code in 2 letters (if not provided  worldwide)</param>
        /// <param name="subcountry">state code</param>
        /// <param name="domainFilter">Filter answers to pages of a designated domain name</param>
        /// <param name="urlFilter">Filter answers to pages URL including a specified string</param>
        /// <param name="categoryFilter">Filter answers to a specific page category</param>
        /// <param name="keywordFilter">Filter answers to pages titles containing a particular keyword</param>
        /// <param name="lines">Get X results (max in one request is 50 please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Pages&gt;</returns>
        List<Pages> PagesGet (int? presetFilter, string fromDate, string toDate, string country, string subcountry, string domainFilter, string urlFilter, int? categoryFilter, string keywordFilter, int? lines, int? offset);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class HistoricalApi : IHistoricalApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="HistoricalApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public HistoricalApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="HistoricalApi"/> class.
        /// </summary>
        /// <returns></returns>
        public HistoricalApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get historical stats for categories 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="keywordFilter">Filter answers to cateogry names containing a particular keyword</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Categories&gt;</returns>
        public List<Categories> CategoriesGet (string country, string subcountry, string fromDate, string toDate, string keywordFilter, int? lines, int? offset)
        {
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling CategoriesGet");
    
            var path = "/categories";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
 if (keywordFilter != null) queryParams.Add("keyword_filter", ApiClient.ParameterToString(keywordFilter)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CategoriesGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CategoriesGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Categories>) ApiClient.Deserialize(response.Content, typeof(List<Categories>), response.Headers);
        }
    
        /// <summary>
        /// Get history for category ID 
        /// </summary>
        /// <param name="id">category id</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Category&gt;</returns>
        public List<Category> CategoryGet (string id, string country, string subcountry, string fromDate, string toDate)
        {
            // verify the required parameter 'id' is set
            if (id == null) throw new ApiException(400, "Missing required parameter 'id' when calling CategoryGet");
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling CategoryGet");
    
            var path = "/category";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (id != null) queryParams.Add("id", ApiClient.ParameterToString(id)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling CategoryGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling CategoryGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Category>) ApiClient.Deserialize(response.Content, typeof(List<Category>), response.Headers);
        }
    
        /// <summary>
        /// Get history for domain name 
        /// </summary>
        /// <param name="domain">domain name (no subdomain allowed)</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Domain&gt;</returns>
        public List<Domain> DomainGet (string domain, string country, string subcountry, string fromDate, string toDate)
        {
            // verify the required parameter 'domain' is set
            if (domain == null) throw new ApiException(400, "Missing required parameter 'domain' when calling DomainGet");
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling DomainGet");
    
            var path = "/domain";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (domain != null) queryParams.Add("domain", ApiClient.ParameterToString(domain)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling DomainGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling DomainGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Domain>) ApiClient.Deserialize(response.Content, typeof(List<Domain>), response.Headers);
        }
    
        /// <summary>
        /// Get historical stats for domains 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="urlFilter">Filter answers to domains including a specified string</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Domains&gt;</returns>
        public List<Domains> DomainsGet (string country, string subcountry, string fromDate, string toDate, string urlFilter, int? lines, int? offset)
        {
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling DomainsGet");
    
            var path = "/domains";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
 if (urlFilter != null) queryParams.Add("url_filter", ApiClient.ParameterToString(urlFilter)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling DomainsGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling DomainsGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Domains>) ApiClient.Deserialize(response.Content, typeof(List<Domains>), response.Headers);
        }
    
        /// <summary>
        /// Get page history for URL 
        /// </summary>
        /// <param name="url">Fully qualified page url. URL needs to be URL encoded</param>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)</param>
        /// <returns>List&lt;Page&gt;</returns>
        public List<Page> PageGet (string url, string country, string subcountry, string fromDate, string toDate)
        {
            // verify the required parameter 'url' is set
            if (url == null) throw new ApiException(400, "Missing required parameter 'url' when calling PageGet");
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling PageGet");
    
            var path = "/page";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (url != null) queryParams.Add("url", ApiClient.ParameterToString(url)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling PageGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling PageGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Page>) ApiClient.Deserialize(response.Content, typeof(List<Page>), response.Headers);
        }
    
        /// <summary>
        /// Get historical stats for pages 
        /// </summary>
        /// <param name="presetFilter">Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone</param>
        /// <param name="fromDate">Datas from YYYY-MM-DD (if not provided, last 30 days)</param>
        /// <param name="toDate">Datas to YYYY-MM-DD (if not provided, last 30 days)</param>
        /// <param name="country">ISO_3166 country code in 2 letters (if not provided  worldwide)</param>
        /// <param name="subcountry">state code</param>
        /// <param name="domainFilter">Filter answers to pages of a designated domain name</param>
        /// <param name="urlFilter">Filter answers to pages URL including a specified string</param>
        /// <param name="categoryFilter">Filter answers to a specific page category</param>
        /// <param name="keywordFilter">Filter answers to pages titles containing a particular keyword</param>
        /// <param name="lines">Get X results (max in one request is 50 please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Pages&gt;</returns>
        public List<Pages> PagesGet (int? presetFilter, string fromDate, string toDate, string country, string subcountry, string domainFilter, string urlFilter, int? categoryFilter, string keywordFilter, int? lines, int? offset)
        {
            // verify the required parameter 'presetFilter' is set
            if (presetFilter == null) throw new ApiException(400, "Missing required parameter 'presetFilter' when calling PagesGet");
    
            var path = "/pages";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (fromDate != null) queryParams.Add("from_date", ApiClient.ParameterToString(fromDate)); // query parameter
 if (toDate != null) queryParams.Add("to_date", ApiClient.ParameterToString(toDate)); // query parameter
 if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (domainFilter != null) queryParams.Add("domain_filter", ApiClient.ParameterToString(domainFilter)); // query parameter
 if (urlFilter != null) queryParams.Add("url_filter", ApiClient.ParameterToString(urlFilter)); // query parameter
 if (categoryFilter != null) queryParams.Add("category_filter", ApiClient.ParameterToString(categoryFilter)); // query parameter
 if (keywordFilter != null) queryParams.Add("keyword_filter", ApiClient.ParameterToString(keywordFilter)); // query parameter
 if (presetFilter != null) queryParams.Add("preset_filter", ApiClient.ParameterToString(presetFilter)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling PagesGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling PagesGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Pages>) ApiClient.Deserialize(response.Content, typeof(List<Pages>), response.Headers);
        }
    
    }
}
