using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ILiveApi
    {
        /// <summary>
        /// Get livedata stats for categories 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="keywordFilter">Filter answers to category names containing a particular keyword</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Categories&gt;</returns>
        List<Categories> LivecategoriesGet (string country, string subcountry, int? hours, string keywordFilter, string languageFilter, int? lines, int? offset);
        /// <summary>
        /// Get livedata stats for domains 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="urlFilter">Filter answers to domains including a specified string</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Domains&gt;</returns>
        List<Domains> LivedomainsGet (string country, string subcountry, string urlFilter, int? hours, int? lines, string languageFilter, int? offset);
        /// <summary>
        /// Get livedata stats for pages 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="presetFilter">Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone</param>
        /// <param name="subcountry">state code</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="onlyNew">Get only pages first seen in the reporting period if set on 1</param>
        /// <param name="domainFilter">Filter answers to pages of a designated domain name</param>
        /// <param name="keywordFilter">Filter answers to pages titles containing a particular keyword</param>
        /// <param name="urlFilter">Filter answers to pages URL including a specified string</param>
        /// <param name="categoryFilter">Filter answers to pages of a designated category id</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="lines">Get X results (max in one request is 50 please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Pages&gt;</returns>
        List<Pages> LivepagesGet (string country, int? presetFilter, string subcountry, int? hours, int? onlyNew, string domainFilter, string keywordFilter, string urlFilter, int? categoryFilter, string languageFilter, int? lines, int? offset);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class LiveApi : ILiveApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="LiveApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public LiveApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="LiveApi"/> class.
        /// </summary>
        /// <returns></returns>
        public LiveApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get livedata stats for categories 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="keywordFilter">Filter answers to category names containing a particular keyword</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Categories&gt;</returns>
        public List<Categories> LivecategoriesGet (string country, string subcountry, int? hours, string keywordFilter, string languageFilter, int? lines, int? offset)
        {
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling LivecategoriesGet");
    
            var path = "/livecategories";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (hours != null) queryParams.Add("hours", ApiClient.ParameterToString(hours)); // query parameter
 if (keywordFilter != null) queryParams.Add("keyword_filter", ApiClient.ParameterToString(keywordFilter)); // query parameter
 if (languageFilter != null) queryParams.Add("language_filter", ApiClient.ParameterToString(languageFilter)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling LivecategoriesGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling LivecategoriesGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Categories>) ApiClient.Deserialize(response.Content, typeof(List<Categories>), response.Headers);
        }
    
        /// <summary>
        /// Get livedata stats for domains 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="subcountry">state code</param>
        /// <param name="urlFilter">Filter answers to domains including a specified string</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="lines">Get X results (max in one request is 10K please use offset paginated results if you need more)</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Domains&gt;</returns>
        public List<Domains> LivedomainsGet (string country, string subcountry, string urlFilter, int? hours, int? lines, string languageFilter, int? offset)
        {
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling LivedomainsGet");
    
            var path = "/livedomains";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (urlFilter != null) queryParams.Add("url_filter", ApiClient.ParameterToString(urlFilter)); // query parameter
 if (hours != null) queryParams.Add("hours", ApiClient.ParameterToString(hours)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (languageFilter != null) queryParams.Add("language_filter", ApiClient.ParameterToString(languageFilter)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling LivedomainsGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling LivedomainsGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Domains>) ApiClient.Deserialize(response.Content, typeof(List<Domains>), response.Headers);
        }
    
        /// <summary>
        /// Get livedata stats for pages 
        /// </summary>
        /// <param name="country">ISO_3166 country code in 2 letters</param>
        /// <param name="presetFilter">Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone</param>
        /// <param name="subcountry">state code</param>
        /// <param name="hours">Get results for last x hours</param>
        /// <param name="onlyNew">Get only pages first seen in the reporting period if set on 1</param>
        /// <param name="domainFilter">Filter answers to pages of a designated domain name</param>
        /// <param name="keywordFilter">Filter answers to pages titles containing a particular keyword</param>
        /// <param name="urlFilter">Filter answers to pages URL including a specified string</param>
        /// <param name="categoryFilter">Filter answers to pages of a designated category id</param>
        /// <param name="languageFilter">Filter answers to pages in specific user language</param>
        /// <param name="lines">Get X results (max in one request is 50 please use offset paginated results if you need more)</param>
        /// <param name="offset">Get paginated results from X offset</param>
        /// <returns>List&lt;Pages&gt;</returns>
        public List<Pages> LivepagesGet (string country, int? presetFilter, string subcountry, int? hours, int? onlyNew, string domainFilter, string keywordFilter, string urlFilter, int? categoryFilter, string languageFilter, int? lines, int? offset)
        {
            // verify the required parameter 'country' is set
            if (country == null) throw new ApiException(400, "Missing required parameter 'country' when calling LivepagesGet");
            // verify the required parameter 'presetFilter' is set
            if (presetFilter == null) throw new ApiException(400, "Missing required parameter 'presetFilter' when calling LivepagesGet");
    
            var path = "/livepages";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (country != null) queryParams.Add("country", ApiClient.ParameterToString(country)); // query parameter
 if (subcountry != null) queryParams.Add("subcountry", ApiClient.ParameterToString(subcountry)); // query parameter
 if (hours != null) queryParams.Add("hours", ApiClient.ParameterToString(hours)); // query parameter
 if (presetFilter != null) queryParams.Add("preset_filter", ApiClient.ParameterToString(presetFilter)); // query parameter
 if (onlyNew != null) queryParams.Add("only_new", ApiClient.ParameterToString(onlyNew)); // query parameter
 if (domainFilter != null) queryParams.Add("domain_filter", ApiClient.ParameterToString(domainFilter)); // query parameter
 if (keywordFilter != null) queryParams.Add("keyword_filter", ApiClient.ParameterToString(keywordFilter)); // query parameter
 if (urlFilter != null) queryParams.Add("url_filter", ApiClient.ParameterToString(urlFilter)); // query parameter
 if (categoryFilter != null) queryParams.Add("category_filter", ApiClient.ParameterToString(categoryFilter)); // query parameter
 if (languageFilter != null) queryParams.Add("language_filter", ApiClient.ParameterToString(languageFilter)); // query parameter
 if (lines != null) queryParams.Add("lines", ApiClient.ParameterToString(lines)); // query parameter
 if (offset != null) queryParams.Add("offset", ApiClient.ParameterToString(offset)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling LivepagesGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling LivepagesGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Pages>) ApiClient.Deserialize(response.Content, typeof(List<Pages>), response.Headers);
        }
    
    }
}
