using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IUserApi
    {
        /// <summary>
        /// Change user&#x27;s activated countries 
        /// </summary>
        /// <param name="countries">json encoded string representing countries to activate</param>
        /// <param name="categories">json encoded string representing categories ID to activate</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserCountriesChangeGet (string countries, string categories);
        /// <summary>
        /// Change user customer id. This function is system reserved 
        /// </summary>
        /// <param name="custid">new customer id for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserCustidChangeGet (string custid);
        /// <summary>
        /// Permanently delete the user 
        /// </summary>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserDeleteGet ();
        /// <summary>
        /// Change user details 
        /// </summary>
        /// <param name="email">new email address for user</param>
        /// <param name="fname">new firstname for user</param>
        /// <param name="lname">new lastname for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserDetailsChangeGet (string email, string fname, string lname);
        /// <summary>
        /// Login user with his credentials 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">password for user</param>
        /// <param name="pin">pin code to validate account creation ; when using pin code, password must be set to \&quot;loginwithpin\&quot;</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        List<UserInfo> UserLoginGet (string email, string password, int? pin);
        /// <summary>
        /// Get messages for user 
        /// </summary>
        /// <param name="message">ID of the requested message. 0 to get the full message list</param>
        /// <returns>List&lt;Message&gt;</returns>
        List<Message> UserMessagesGet (int? message);
        /// <summary>
        /// Change user password 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">current password for user</param>
        /// <param name="newpassword">new password to set up for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserPasswordChangeGet (string email, string password, string newpassword);
        /// <summary>
        /// Reset user password 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        List<TransactionInfo> UserPasswordResetGet (string email);
        /// <summary>
        /// Refresh user rights with his Customer ID. This function is system reserved 
        /// </summary>
        /// <param name="custid">Customer ID for the user</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        List<UserInfo> UserRefreshSubscriptionGet (string custid);
        /// <summary>
        /// Login user with his credentials 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">password for user</param>
        /// <param name="fname">new firstname for user</param>
        /// <param name="lname">new lastname for user</param>
        /// <param name="referrer">referrer for this user. should be urlencoded</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        List<UserInfo> UserRegisterGet (string email, string password, string fname, string lname, string referrer);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class UserApi : IUserApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public UserApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="UserApi"/> class.
        /// </summary>
        /// <returns></returns>
        public UserApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Change user&#x27;s activated countries 
        /// </summary>
        /// <param name="countries">json encoded string representing countries to activate</param>
        /// <param name="categories">json encoded string representing categories ID to activate</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserCountriesChangeGet (string countries, string categories)
        {
            // verify the required parameter 'countries' is set
            if (countries == null) throw new ApiException(400, "Missing required parameter 'countries' when calling UserCountriesChangeGet");
            // verify the required parameter 'categories' is set
            if (categories == null) throw new ApiException(400, "Missing required parameter 'categories' when calling UserCountriesChangeGet");
    
            var path = "/user_countries_change";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (countries != null) queryParams.Add("countries", ApiClient.ParameterToString(countries)); // query parameter
 if (categories != null) queryParams.Add("categories", ApiClient.ParameterToString(categories)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserCountriesChangeGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserCountriesChangeGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Change user customer id. This function is system reserved 
        /// </summary>
        /// <param name="custid">new customer id for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserCustidChangeGet (string custid)
        {
            // verify the required parameter 'custid' is set
            if (custid == null) throw new ApiException(400, "Missing required parameter 'custid' when calling UserCustidChangeGet");
    
            var path = "/user_custid_change";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (custid != null) queryParams.Add("custid", ApiClient.ParameterToString(custid)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserCustidChangeGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserCustidChangeGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Permanently delete the user 
        /// </summary>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserDeleteGet ()
        {
    
            var path = "/user_delete";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserDeleteGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserDeleteGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Change user details 
        /// </summary>
        /// <param name="email">new email address for user</param>
        /// <param name="fname">new firstname for user</param>
        /// <param name="lname">new lastname for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserDetailsChangeGet (string email, string fname, string lname)
        {
            // verify the required parameter 'email' is set
            if (email == null) throw new ApiException(400, "Missing required parameter 'email' when calling UserDetailsChangeGet");
            // verify the required parameter 'fname' is set
            if (fname == null) throw new ApiException(400, "Missing required parameter 'fname' when calling UserDetailsChangeGet");
            // verify the required parameter 'lname' is set
            if (lname == null) throw new ApiException(400, "Missing required parameter 'lname' when calling UserDetailsChangeGet");
    
            var path = "/user_details_change";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (email != null) queryParams.Add("email", ApiClient.ParameterToString(email)); // query parameter
 if (fname != null) queryParams.Add("fname", ApiClient.ParameterToString(fname)); // query parameter
 if (lname != null) queryParams.Add("lname", ApiClient.ParameterToString(lname)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserDetailsChangeGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserDetailsChangeGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Login user with his credentials 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">password for user</param>
        /// <param name="pin">pin code to validate account creation ; when using pin code, password must be set to \&quot;loginwithpin\&quot;</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        public List<UserInfo> UserLoginGet (string email, string password, int? pin)
        {
            // verify the required parameter 'email' is set
            if (email == null) throw new ApiException(400, "Missing required parameter 'email' when calling UserLoginGet");
            // verify the required parameter 'password' is set
            if (password == null) throw new ApiException(400, "Missing required parameter 'password' when calling UserLoginGet");
    
            var path = "/user_login";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (email != null) queryParams.Add("email", ApiClient.ParameterToString(email)); // query parameter
 if (password != null) queryParams.Add("password", ApiClient.ParameterToString(password)); // query parameter
 if (pin != null) queryParams.Add("pin", ApiClient.ParameterToString(pin)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserLoginGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserLoginGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<UserInfo>) ApiClient.Deserialize(response.Content, typeof(List<UserInfo>), response.Headers);
        }
    
        /// <summary>
        /// Get messages for user 
        /// </summary>
        /// <param name="message">ID of the requested message. 0 to get the full message list</param>
        /// <returns>List&lt;Message&gt;</returns>
        public List<Message> UserMessagesGet (int? message)
        {
    
            var path = "/user_messages";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (message != null) queryParams.Add("message", ApiClient.ParameterToString(message)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserMessagesGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserMessagesGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Message>) ApiClient.Deserialize(response.Content, typeof(List<Message>), response.Headers);
        }
    
        /// <summary>
        /// Change user password 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">current password for user</param>
        /// <param name="newpassword">new password to set up for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserPasswordChangeGet (string email, string password, string newpassword)
        {
            // verify the required parameter 'email' is set
            if (email == null) throw new ApiException(400, "Missing required parameter 'email' when calling UserPasswordChangeGet");
            // verify the required parameter 'password' is set
            if (password == null) throw new ApiException(400, "Missing required parameter 'password' when calling UserPasswordChangeGet");
            // verify the required parameter 'newpassword' is set
            if (newpassword == null) throw new ApiException(400, "Missing required parameter 'newpassword' when calling UserPasswordChangeGet");
    
            var path = "/user_password_change";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (email != null) queryParams.Add("email", ApiClient.ParameterToString(email)); // query parameter
 if (password != null) queryParams.Add("password", ApiClient.ParameterToString(password)); // query parameter
 if (newpassword != null) queryParams.Add("newpassword", ApiClient.ParameterToString(newpassword)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserPasswordChangeGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserPasswordChangeGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Reset user password 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <returns>List&lt;TransactionInfo&gt;</returns>
        public List<TransactionInfo> UserPasswordResetGet (string email)
        {
            // verify the required parameter 'email' is set
            if (email == null) throw new ApiException(400, "Missing required parameter 'email' when calling UserPasswordResetGet");
    
            var path = "/user_password_reset";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (email != null) queryParams.Add("email", ApiClient.ParameterToString(email)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserPasswordResetGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserPasswordResetGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<TransactionInfo>) ApiClient.Deserialize(response.Content, typeof(List<TransactionInfo>), response.Headers);
        }
    
        /// <summary>
        /// Refresh user rights with his Customer ID. This function is system reserved 
        /// </summary>
        /// <param name="custid">Customer ID for the user</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        public List<UserInfo> UserRefreshSubscriptionGet (string custid)
        {
            // verify the required parameter 'custid' is set
            if (custid == null) throw new ApiException(400, "Missing required parameter 'custid' when calling UserRefreshSubscriptionGet");
    
            var path = "/user_refresh_subscription";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (custid != null) queryParams.Add("custid", ApiClient.ParameterToString(custid)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserRefreshSubscriptionGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserRefreshSubscriptionGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<UserInfo>) ApiClient.Deserialize(response.Content, typeof(List<UserInfo>), response.Headers);
        }
    
        /// <summary>
        /// Login user with his credentials 
        /// </summary>
        /// <param name="email">email address for user</param>
        /// <param name="password">password for user</param>
        /// <param name="fname">new firstname for user</param>
        /// <param name="lname">new lastname for user</param>
        /// <param name="referrer">referrer for this user. should be urlencoded</param>
        /// <returns>List&lt;UserInfo&gt;</returns>
        public List<UserInfo> UserRegisterGet (string email, string password, string fname, string lname, string referrer)
        {
            // verify the required parameter 'email' is set
            if (email == null) throw new ApiException(400, "Missing required parameter 'email' when calling UserRegisterGet");
            // verify the required parameter 'password' is set
            if (password == null) throw new ApiException(400, "Missing required parameter 'password' when calling UserRegisterGet");
            // verify the required parameter 'fname' is set
            if (fname == null) throw new ApiException(400, "Missing required parameter 'fname' when calling UserRegisterGet");
            // verify the required parameter 'lname' is set
            if (lname == null) throw new ApiException(400, "Missing required parameter 'lname' when calling UserRegisterGet");
    
            var path = "/user_register";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (email != null) queryParams.Add("email", ApiClient.ParameterToString(email)); // query parameter
 if (password != null) queryParams.Add("password", ApiClient.ParameterToString(password)); // query parameter
 if (fname != null) queryParams.Add("fname", ApiClient.ParameterToString(fname)); // query parameter
 if (lname != null) queryParams.Add("lname", ApiClient.ParameterToString(lname)); // query parameter
 if (referrer != null) queryParams.Add("referrer", ApiClient.ParameterToString(referrer)); // query parameter
                        
            // authentication setting, if any
            String[] authSettings = new String[] { "bearerAuth" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling UserRegisterGet: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling UserRegisterGet: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<UserInfo>) ApiClient.Deserialize(response.Content, typeof(List<UserInfo>), response.Headers);
        }
    
    }
}
